RequestHandle

Enum RequestHandle 

pub enum RequestHandle<Out> {
    Never,
    Once(Box<dyn FnOnce(Out) + Send>),
    Many(Box<dyn Fn(Out) -> Result<(), ()> + Send>),
}
Resolve is a callback used to resolve an effect request and continue one of the capability Tasks running on the executor.

Variants



Never



Once(Box<dyn FnOnce(Out) + Send>)



Many(Box<dyn Fn(Out) -> Result<(), ()> + Send>)

Implementations

Source

impl<Output> RequestHandle<Output>

pub fn resolve(&mut self, output: Output) -> Result<(), ResolveError>

Resolve the request with the given output.

Errors

Returns an error if the request is not expected to be resolved.