pub trait EffectFFI: Effect {
type Ffi: Serialize;
// Required method
fn serialize<T: FfiFormat>(self) -> (Self::Ffi, ResolveSerialized<T>);
}Expand description
Required Associated Types
Required Methods
Sourcefn serialize<T: FfiFormat>(self) -> (Self::Ffi, ResolveSerialized<T>)
fn serialize<T: FfiFormat>(self) -> (Self::Ffi, ResolveSerialized<T>)
Converts the Effect into its FFI counterpart and returns it alongside
a deserializing version of the resolve callback for the request that the
original Effect was carrying.
You should not need to call this method directly. It is called by
the Bridge
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.