pub struct Core<A>where
A: App,{ /* private fields */ }Expand description
The Crux core. Create an instance of this type with your App type as the type parameter
The core interface allows passing in events of type A::Event using Core::process_event.
It will return back an effect of type Ef, containing an effect request, with the input needed for processing
the effect. the Effect type can be used by shells to dispatch to the right capability implementation.
The result of the capability’s work can then be sent back to the core using Core::resolve, passing
in the request and the corresponding capability output type.
Implementations
Sourceimpl<A> Core<A>
impl<A> Core<A>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create an instance of the Crux core to start a Crux application, e.g.
If you want to construct App and App::Model yourself instead of using default, call Self::new_with
let core: Core<MyApp> = Core::new();Sourceimpl<A> Core<A>where
A: App,
impl<A> Core<A>where
A: App,
Sourcepub fn new_with(app: A, model: A::Model) -> Self
pub fn new_with(app: A, model: A::Model) -> Self
Create an instance of the Crux core to start a Crux application with a given App and App::Model
let app = MyApp::new();
let model = MyModel::new();
let core = Core::new_with(app, model);Sourcepub fn process_event(&self, event: A::Event) -> Vec<A::Effect>
pub fn process_event(&self, event: A::Event) -> Vec<A::Effect>
Run the app’s update function with a given event, returning a vector of
effect requests.
Panics
Panics if the model RwLock was poisoned.
Sourcepub fn resolve<Output>(
&self,
request: &mut impl Resolvable<Output>,
result: Output,
) -> Result<Vec<A::Effect>, ResolveError>
pub fn resolve<Output>( &self, request: &mut impl Resolvable<Output>, result: Output, ) -> Result<Vec<A::Effect>, ResolveError>
Resolve an effect request for operation Op with the corresponding result.
Note that the request is borrowed mutably. When a request that is expected to
only be resolved once is passed in, it will be consumed and changed to a request
which can no longer be resolved.
Errors
Errors if the request cannot (or should not) be resolved.