pub trait Effect: Send + 'static { }Expand description
Implemented automatically with the effect macro from crux_macros.
This is a marker trait to ensure the macro generated traits are present on the effect type.
You should annotate your type with #[effect] to implement this trait.